NBA.Live.Odds (nba_api_ex v0.1.0)
View SourceFetches live NBA odds data.
Summary
Functions
Fetches live NBA odds data.
Parameters
opts: A keyword list of additional options for the request, such as headers or timeout settings.- For a list of available options, see the Req documentation.
Returns
{:ok, odds}: A map containing the odds data.{:error, reason}: An error tuple with the reason for failure.
Example
iex> NBA.Live.Odds.get()
{:ok, [%{"gameId" => "0042400311", ...}, ...]}