NBA.Live.Scoreboard (nba_api_ex v0.1.0)
View SourceFetches the NBA scoreboard data for a specific date.
Summary
Functions
Fetches live NBA scoreboard data.
Parameters
opts: A keyword list of additional options for the request, such as headers or timeout settings.- For a list of available options, see the Req documentation.
Returns
{:ok, scoreboard}: A map containing the scoreboard data.{:error, reason}: An error tuple with the reason for failure.
Example
iex> NBA.Live.Scoreboard.get()
{:ok, [%{"gameId" => "0042400311", ...}, ...]}