NBA.Stats.FranchiseLeaders (nba_api_ex v0.1.0)
View SourceFetches franchise leaders data from the NBA stats API.
Summary
Functions
Fetches franchise leaders data for a specific team.
Functions
Fetches franchise leaders data for a specific team.
Parameters
params: A keyword list of parameters for the request.opts: Additional options for the request, such as headers or timeout settings.- For a full list of options, see the Req documentation.
Returns
{:ok, response}: A map containing the franchise leaders data.{:error, reason}: An error tuple with the reason for failure.
Example
iex> NBA.Stats.FranchiseLeaders.get(TeamID: 1610612739) {:ok, %{data: [%{"Leader" => "LeBron James", "Value" => 35000}]}}