NBA.Stats.LeagueDashPtStats (nba_api_ex v0.1.0)

Provides functions to interact with the NBA stats API for league player tracking shot stats.

See get/2 for parameter and usage details.

Summary

Functions

get(params \\ [PerMode: "PerGame", LeagueID: "00", SeasonType: "Regular Season", PtMeasureType: "SpeedDistance", PORound: 0, PlayerID: nil, TeamID: 0, Outcome: nil, Location: nil, Month: 0, SeasonSegment: nil, DateFrom: nil, DateTo: nil, OpponentTeamID: 0, VsConference: nil, VsDivision: nil, Conference: nil, Division: nil, GameSegment: nil, Period: 0, LastNGames: 0, DraftYear: nil, DraftPick: nil, College: nil, Country: nil, Height: nil, Weight: nil, PlayerExperience: nil, PlayerPosition: nil, StarterBench: nil, DribbleRange: nil, ShotClockRange: nil, TouchTimeRange: nil, ISTRound: nil], opts \\ [])

(since 0.1.0)

Fetches league player tracking data.

Parameters

  • params: A keyword list of parameters to filter the data.
    • College: The college of the player.

      • Type(s): String
      • Example: College: "Duke"
      • Default: nil
    • Conference: The conference of the team.

      • Type(s): String
      • Example: Conference: "West"
      • Default: nil
      • Valueset:
        • "East"
        • "West"
    • Country: The country of the player.

      • Type(s): String
      • Example: Country: "USA"
      • Default: nil
    • DateFrom: The start date for filtering.

      • Type(s): String
      • Example: DateFrom: "2023-10-01"
      • Default: nil
    • DateTo: The end date for filtering.

      • Type(s): String
      • Example: DateTo: "2024-04-15"
      • Default: nil
    • Division: The division of the team.

      • Type(s): String
      • Example: Division: "Pacific"
      • Default: nil
      • Valueset:
        • "Atlantic"
        • "Central"
        • "Southeast"
        • "Northwest"
        • "Pacific"
        • "Southwest"
    • DraftPick: The draft pick of the player.

      • Type(s): String
      • Example: DraftPick: "1"
      • Default: nil
    • DraftYear: The draft year of the player.

      • Type(s): String
      • Example: DraftYear: "2018"
      • Default: nil
    • DribbleRange: The dribble range for filtering.

      • Type(s): String
      • Example: DribbleRange: "0 Dribbles"
      • Default: nil
      • Valueset:
        • "0 Dribbles"
        • "1 Dribble"
        • "2 Dribbles"
        • "3-6 Dribbles"
        • "7+ Dribbles"
    • GameSegment: The segment of the game.

      • Type(s): String
      • Example: GameSegment: "First Half"
      • Default: nil
      • Valueset:
        • "First Half"
        • "Second Half"
        • "Overtime"
    • Height: The height of the player.

      • Type(s): String
      • Example: Height: "6-7"
      • Default: nil
    • ISTRound: The round of the In-Season Tournament.

      • Type(s): String
      • Example: ISTRound: "All IST"
      • Default: nil
    • LastNGames: The number of last games to consider.

      • Type(s): Integer
      • Example: LastNGames: 5
      • Default: 0
    • LeagueID: The league ID.

      • Type(s): String
      • Example: LeagueID: "00"
      • Default: "00"
      • Valueset:
        • "00"
        • "10"
        • "20"
    • Location: The location of the game.

      • Type(s): String
      • Example: Location: "Home"
      • Default: nil
      • Valueset:
        • "Home"
        • "Away"
    • Month: The month of the season.

      • Type(s): Integer
      • Example: Month: 1
      • Default: 0
    • OpponentTeamID: The ID of the opponent team.

      • Type(s): Integer | String

      • Example: OpponentTeamID: 1610612739
      • Default: 0
    • Outcome: The outcome of the game.

      • Type(s): String
      • Example: Outcome: "W"
      • Default: nil
      • Valueset:
        • "W"
        • "L"
    • PerMode: How stats are aggregated.

      • Type(s): String
      • Example: PerMode: "PerGame"
      • Default: "PerGame"
      • Valueset:
        • "Totals"
        • "PerGame"
        • "Per48"
        • "Per40"
        • "Per36"
        • "PerMinute"
        • "PerPossession"
        • "PerPlay"
        • "Per100Possessions"
        • "Per100Plays"
    • Period: The period of the game.

      • Type(s): Integer
      • Example: Period: 1
      • Default: 0
    • PlayerExperience: The experience level of the player.

      • Type(s): String
      • Example: PlayerExperience: "Rookie"
      • Default: nil
      • Valueset:
        • "Rookie"
        • "Sophomore"
        • "Veteran"
    • PlayerID: The NBA player ID (use nil for league-wide).

    • PlayerPosition: The position of the player.

      • Type(s): String
      • Example: PlayerPosition: "F"
      • Default: nil
      • Valueset:
        • "F"
        • "C"
        • "G"
    • PtMeasureType: The type of player tracking measure.

    • Type(s): String

      • Example: PtMeasureType: "SpeedDistance"
      • Default: "SpeedDistance"
      • Valueset:
        • "SpeedDistance"
        • "Rebounding"
        • "Possessions"
        • "CatchShoot"
        • "PullUpShot"
        • "Defense"
        • "Drives"
        • "Passing"
        • "ElbowTouch"
        • "PostTouch"
        • "PaintTouch"
        • "Efficiency"
    • PORound: The playoff round.

      • Type(s): Integer
      • Example: PORound: 1
      • Default: 0
    • Season: (Required) The season for which to fetch data.

      • Type(s): String
      • Example: Season: "2024-25"
      • Default: nil
    • SeasonSegment: The segment of the season.

      • Type(s): String
      • Example: SeasonSegment: "Post All Star"
      • Default: nil
      • Valueset:
        • "Pre All Star"
        • "Post All Star"
    • SeasonType: The type of season.

      • Type(s): String
      • Example: SeasonType: "Playoffs"
      • Default: "Regular Season"
      • Valueset:
        • "Regular Season"
        • "Playoffs"
        • "Pre Season"
        • "All Star"
        • "Play In"
    • ShotClockRange: The range of the shot clock.

      • Type(s): String
      • Example: ShotClockRange: "24+"
      • Default: nil
      • Valueset:
        • "24+"
        • "22-18"
        • "15-7"
        • "4-0"
        • "NA"
    • StarterBench: Whether the player is a starter or bench.

      • Type(s): String
      • Example: StarterBench: "Bench"
      • Default: nil
      • Valueset:
        • "Starter"
        • "Bench"
    • TeamID: The ID of the team.

    • TouchTimeRange: The touch time range for filtering.

      • Type(s): String
      • Example: TouchTimeRange: "Touch < 2 Seconds"
      • Default: nil
      • Valueset:
        • "Touch < 2 Seconds"
        • "Touch 2-6 Seconds"
        • "Touch 6+ Seconds"
    • VsConference: The conference of the opponent.

      • Type(s): String
      • Example: VsConference: "East"
      • Default: nil
      • Valueset:
        • "East"
        • "West"
    • VsDivision: The division of the opponent.

      • Type(s): String
      • Example: VsDivision: "Central"
      • Default: nil
      • Valueset:
        • "Atlantic"
        • "Central"
        • "Southeast"
        • "Northwest"
        • "Pacific"
        • "Southwest"
    • Weight: The weight of the player.

      • Type(s): String
      • Example: Weight: "220"
      • Default: nil

Returns

  • {:ok, data}: On success, returns the data from the API.
  • {:error, reason}: On failure, returns an error tuple with the reason.

Example

iex> NBA.Stats.LeagueDashPtStats.get(Season: "2024-25")
{:ok, %{"LeagueDashPtStats" => [%{...}, ...]}}

get!(params \\ [], opts \\ [])

(since 0.1.0)