NBA.Stats.MatchupsRollup (nba_api_ex v0.1.0)

Provides functions to interact with the NBA stats API for MatchupsRollup.

See get/2 for parameter and usage details.

Summary

Functions

get(params \\ [LeagueID: "00", PerMode: "Totals", Season: nil, SeasonType: "Regular Season", OffTeamID: nil, OffPlayerID: nil, DefTeamID: nil, DefPlayerID: nil], opts \\ [])

(since 0.1.0)

Fetches MatchupsRollup data.

Parameters

  • params: A keyword list of parameters to filter the data.

    • Season: (Required) The season for which to fetch data.

      • Type(s): String
      • Example: Season: "2024-25"
      • Default: nil
      • Pattern: ^(\d{4}-\d{2})$
    • DefPlayerID: Defensive player ID.

      • Type(s): Integer | String

      • Example: DefPlayerID: 1629029
      • Default: nil
    • DefTeamID: Defensive team ID.

      • Type(s): Integer | String

      • Example: DefTeamID: 1610612737
      • Default: nil
    • LeagueID: The league ID.

      • Type(s): String
      • Example: LeagueID: "00"
      • Default: "00"
      • Valueset:
        • "00" (NBA)
        • "01" (ABA)
        • "10" (WNBA)
        • "20" (G League)
    • OffPlayerID: Offensive player ID.

      • Type(s): Integer | String

      • Example: OffPlayerID: 1629029
      • Default: nil
    • OffTeamID: Offensive team ID.

      • Type(s): Integer | String

      • Example: OffTeamID: 1610612737
      • Default: nil
    • PerMode: How to aggregate stats.

      • Type(s): String
      • Example: PerMode: "Totals"
      • Default: nil
      • Valueset:
        • "Totals"
        • "PerGame"
    • SeasonType: The type of season.

      • Type(s): String
      • Example: SeasonType: "Regular Season"
      • Default: "Regular Season"
      • Valueset:
        • "Regular Season"
        • "Pre Season"
        • "Playoffs"
        • "Pre-Season"
  • opts: A keyword list of additional options for the request, such as headers or timeout settings.

Returns

  • {:ok, data}: On success, returns the data from the API.
  • {:error, reason}: On failure, returns an error tuple with the reason.

Example

iex> NBA.Stats.MatchupsRollup.get(LeagueID: "00", PerMode: "Totals", Season: "2024-25", SeasonType: "Regular Season")
{:ok, %{"MatchupsRollup" => [%{...}, ...]}}

get!(params \\ [], opts \\ [])

(since 0.1.0)