NBA.Stats.PlayerAwards (nba_api_ex v0.1.0)
View SourceFetches award data for a specific NBA player.
Summary
Functions
Fetches awards for a specific player.
Functions
Fetches awards for a specific player.
Parameters
params: A keyword list of parameters for the request.opts: A keyword list of options for the request, such as headers or timeout settings.- For a list of available options, see the Req documentation.
Returns
{:ok, awards}: A map of awards grouped by award name.{:error, reason}: An error tuple with the reason for failure.
Example
iex> NBA.Stats.PlayerAwards.get(PlayerID: "2544")
{:ok, %{"All-NBA" => [%{"DESCRIPTION" => "All-NBA", ...}]}}