NBA.Stats.PlayerDashboard (nba_api_ex v0.1.0)
View SourceProvides functions to interact with the NBA stats API for PlayerDashboard.
See get/2 for parameter and usage details.
Summary
Functions
get(type, params \\ [LastNGames: 0, MeasureType: "Base", Month: 0, OpponentTeamID: 0, PaceAdjust: "N", PerMode: "PerGame", Period: 0, PlayerID: nil, PlusMinus: "N", Rank: "N", Season: nil, SeasonType: "Regular Season", TeamID: 0, VsDivision: nil, VsConference: nil, ShotClockRange: nil, SeasonSegment: nil, PORound: nil, Outcome: nil, Location: nil, LeagueID: "00", GameSegment: nil, DateTo: nil, DateFrom: nil], opts \\ [])
(since 0.1.0)Fetches PlayerDashboardByClutch data.
Parameters
type: The type of data to fetch. This should be one of the keys in@endpoints, such as:clutch,:game_splits, etc.:clutch: Fetches clutch stats.:game_splits: Fetches game splits stats.:general_splits: Fetches general splits stats.:last_n_games: Fetches stats for the last N games.:shooting_splits: Fetches shooting splits stats.:team_performance: Fetches team performance stats.:year_over_year: Fetches year-over-year stats.
params: A keyword list of parameters to filter the data.PlayerID: (Required) The player ID.Season: (Required) The season.- Type(s):
String - Example:
Season: "2024-25" - Default:
nil
- Type(s):
LastNGames: Number of last games to include.- Type(s):
Integer - Example:
LastNGames: 10 - Default:
0
- Type(s):
MeasureType: The type of measure.- Type(s):
String - Example:
MeasureType: "Base" - Default:
"Base" - Valueset:
"Base""Advanced""Misc""Four Factors""Scoring""Opponent""Usage"
- Type(s):
Month: The month number.- Type(s):
Integer - Example:
Month: 1 - Default:
0
- Type(s):
OpponentTeamID: The opponent team ID.PaceAdjust: Whether to adjust for pace.- Type(s):
String - Example:
PaceAdjust: "Y" - Default:
"N" - Valueset:
"Y""N"
- Type(s):
PerMode: How to aggregate stats.- Type(s):
String - Example:
PerMode: "PerGame" - Default:
"PerGame" - Valueset:
"Totals""PerGame""MinutesPer""Per48""Per40""Per36""PerMinute""PerPossession""PerPlay""Per100Possessions""Per100Plays"
- Type(s):
Period: The period number.- Type(s):
Integer - Example:
Period: 1 - Default:
0
- Type(s):
PlusMinus: Whether to include plus/minus.- Type(s):
String - Example:
PlusMinus: "Y" - Default:
"N" - Valueset:
"Y""N"
- Type(s):
Rank: Whether to include rank.- Type(s):
String - Example:
Rank: "Y" - Default:
"N" - Valueset:
"Y""N"
- Type(s):
SeasonType: The type of season.- Type(s):
String - Example:
SeasonType: "Regular Season" - Default:
"Regular Season" - Valueset:
"Regular Season""Pre Season""Playoffs"
- Type(s):
VsDivision: The vs division.- Type(s):
String - Example:
VsDivision: "Atlantic" - Default:
nil - Valueset:
"Atlantic""Central""Northwest""Pacific""Southeast""Southwest""East""West"
- Type(s):
VsConference: The vs conference.- Type(s):
String - Example:
VsConference: "East" - Default:
nil - Valueset:
"East""West"
- Type(s):
ShotClockRange: The shot clock range.- Type(s):
String - Example:
ShotClockRange: "24-22" - Default:
nil - Valueset:
"24-22""22-18 Very Early""18-15 Early""15-7 Average""7-4 Late""4-0 Very Late""ShotClock Off"
- Type(s):
SeasonSegment: The season segment.- Type(s):
String - Example:
SeasonSegment: "Pre All-Star" - Default:
nil - Valueset:
"Post All-Star""Pre All-Star"
- Type(s):
TeamID: The team ID.PORound: The playoff round.- Type(s):
Integer - Example:
PORound: 1 - Default:
nil
- Type(s):
Outcome: The outcome.- Type(s):
String - Example:
Outcome: "W" - Default:
nil - Valueset:
"W""L"
- Type(s):
Location: The location.- Type(s):
String - Example:
Location: "Home" - Default:
nil - Valueset:
"Home""Road"
- Type(s):
LeagueID: The league ID.- Type(s):
String - Example:
LeagueID: "00" - Default:
"00" - Valueset:
"00"(NBA)"01"(ABA)"10"(WNBA)"20"(G League)
- Type(s):
GameSegment: The game segment.- Type(s):
String - Example:
GameSegment: "First Half" - Default:
nil - Valueset:
"First Half""Overtime""Second Half"
- Type(s):
DateTo: The end date.- Type(s):
String - Example:
DateTo: "2024-01-31" - Default:
nil
- Type(s):
DateFrom: The start date.- Type(s):
String - Example:
DateFrom: "2024-01-01" - Default:
nil
- Type(s):
opts: A keyword list of additional options for the request, such as headers or timeout settings.- For a full list of options, see the Req documentation.
Returns
{:ok, data}: On success, returns the data from the API.{:error, reason}: On failure, returns an error tuple with the reason.
Example
iex> NBA.Stats.PlayerDashboard.get(:clutch, PlayerID: 201939, Season: "2024-25")
{:ok, %{"PlayerDashboardByClutch" => [%{...}, ...]}}