NBA.Stats.PlayerEstimatedMetrics (nba_api_ex v0.1.0)
View SourceProvides functions to interact with the NBA stats API for PlayerEstimatedMetrics.
See get/2 for parameter and usage details.
Summary
Functions
Fetches PlayerEstimatedMetrics data.
Functions
Fetches PlayerEstimatedMetrics data.
Parameters
params: A keyword list of parameters to filter the data.Season: (Required) The season.- Type(s):
String - Example:
Season: "2024-25" - Default:
nil
- Type(s):
LeagueID: The league ID.- Type(s):
String - Example:
LeagueID: "00" - Default:
"00" - Valueset:
"00"(NBA)"01"(ABA)"10"(WNBA)"20"(G League)
- Type(s):
SeasonType: The type of season.- Type(s):
String - Example:
SeasonType: "Regular Season" - Default:
"Regular Season"
- Type(s):
opts: A keyword list of additional options for the request, such as headers or timeout settings.- For a full list of options, see the Req documentation.
Returns
{:ok, data}: On success, returns the data from the API.{:error, reason}: On failure, returns an error tuple with the reason.
Example
iex> NBA.Stats.PlayerEstimatedMetrics.get(Season: "2024-25")
{:ok, [%{...}, ...]}