NBA.Stats.PlayerFantasyProfileBarGraph (nba_api_ex v0.1.0)

Provides functions to interact with the NBA stats API for PlayerFantasyProfileBarGraph.

See get/2 for parameter and usage details.

Summary

Functions

get(params \\ [PlayerID: nil, Season: nil, SeasonType: nil, LeagueID: "00"], opts \\ [])

(since 0.1.0)

Fetches PlayerFantasyProfileBarGraph data.

Parameters

  • params: A keyword list of parameters to filter the data.

    • PlayerID: (Required) The player ID.

    • Season: (Required) The season.

      • Type(s): String
      • Example: Season: "2024-25"
      • Default: nil
    • SeasonType: The type of season.

      • Type(s): String
      • Example: SeasonType: "Regular Season"
      • Default: nil
      • Valueset:
        • "Regular Season"
        • "Pre Season"
        • "Playoffs"
        • "All Star"
    • LeagueID: The league ID.

      • Type(s): String
      • Example: LeagueID: "00"
      • Default: nil
      • Valueset:
        • "00" (NBA)
        • "01" (ABA)
        • "10" (WNBA)
        • "20" (G League)
  • opts: A keyword list of additional options for the request, such as headers or timeout settings.

Returns

  • {:ok, data}: On success, returns the data from the API.
  • {:error, reason}: On failure, returns an error tuple with the reason.

Example

iex> NBA.Stats.PlayerFantasyProfileBarGraph.get(PlayerID: 201939, Season: "2024-25")
{:ok, %{"PlayerFantasyProfileBarGraph" => [%{...}, ...]}}

get!(params \\ [], opts \\ [])

(since 0.1.0)