NBA.Stats.PlayoffPicture (nba_api_ex v0.1.0)

Provides functions to interact with the NBA stats API for PlayoffPicture.

See get/2 for parameter and usage details.

Summary

Functions

get(params \\ [LeagueID: "00", SeasonID: nil], opts \\ [])

(since 0.1.0)

Fetches PlayoffPicture data.

Parameters

  • params: A keyword list of parameters to filter the data.

    • LeagueID: (Required) The league ID.

      • Type(s): String
      • Example: LeagueID: "00"
      • Default: "00"
      • Pattern: ^\d{2}$
    • SeasonID: The season ID.

      • Type(s): String
      • Example: SeasonID: "22022"
      • Default: nil
  • opts: A keyword list of additional options for the request, such as headers or timeout settings.

Returns

  • {:ok, data}: On success, returns the data from the API.
  • {:error, reason}: On failure, returns an error tuple with the reason.

Example

iex> NBA.Stats.PlayoffPicture.get(LeagueID: "00", SeasonID: "22022")
{:ok, %{"PlayoffPicture" => [%{...}, ...]}}

get!(params \\ [], opts \\ [])

(since 0.1.0)