NBA.Stats.TeamDetails (nba_api_ex v0.1.0)

Provides functions to interact with the NBA stats API for TeamDetails.

See get/2 for parameter and usage details.

Summary

Functions

get(params \\ [TeamID: nil], opts \\ [])

(since 0.1.0)

Fetches TeamDetails data.

Parameters

  • params: A keyword list of parameters to filter the data.

    • TeamID: (Required) The team ID.
  • opts: A keyword list of additional options for the request, such as headers or timeout settings.

Returns

  • {:ok, data}: On success, returns the data from the API.
  • {:error, reason}: On failure, returns an error tuple with the reason.

Example

iex> NBA.Stats.TeamDetails.get(TeamID: 1610612744)
{:ok, %{"TeamDetails" => [%{...}, ...]}}

get!(params \\ [], opts \\ [])

(since 0.1.0)