NBA.Stats.TeamEstimatedMetrics (nba_api_ex v0.1.0)

Provides functions to interact with the NBA stats API for TeamEstimatedMetrics.

See get/2 for parameter and usage details.

Summary

Functions

get(params \\ [LeagueID: "00", Season: nil, SeasonType: "Regular Season"], opts \\ [])

(since 0.1.0)

Fetches TeamEstimatedMetrics data.

Parameters

  • params: A keyword list of parameters to filter the data.

    • Season: (Required) The season.

    • LeagueID: The league ID.

    • SeasonType: The season type.

      • Type(s): String
      • Default: "Regular Season"
  • opts: A keyword list of additional options for the request, such as headers or timeout settings.

Returns

  • {:ok, data}: On success, returns the data from the API.
  • {:error, reason}: On failure, returns an error tuple with the reason.

Example

iex> NBA.Stats.TeamEstimatedMetrics.get(Season: "2024-25")
{:ok, %{"TeamEstimatedMetrics" => [%{...}, ...]}}

get!(params \\ [], opts \\ [])

(since 0.1.0)