NBA.Stats.TeamYearByYearStats (nba_api_ex v0.1.0)

Provides functions to interact with the NBA stats API for TeamYearByYearStats.

See get/2 for parameter and usage details.

Summary

Functions

get(params \\ [LeagueID: "00", PerMode: "Totals", SeasonType: "Regular Season", TeamID: nil], opts \\ [])

(since 0.1.0)

Parameters

  • params: A keyword list of parameters to filter the data.

    • TeamID: (Required) The team ID.

    • LeagueID: The league ID (2-digit string).

      • Type(s): String
      • Default: "00"
      • Valueset:
        • "00"
        • "10"
    • PerMode: The per mode for stats.

      • Type(s): String
      • Default: "Totals"
      • Valueset:
        • "Totals"
        • "PerGame"
    • SeasonType: The season type.

      • Type(s): String
      • Default: "Regular Season"
      • Valueset:
        • "Regular Season"
        • "Pre Season"
        • "Playoffs"
        • "All Star"
  • opts: A keyword list of additional options for the request, such as headers or timeout settings.

Returns

  • {:ok, data}: On success, returns the data from the API.
  • {:error, reason}: On failure, returns an error tuple with the reason.

Example

iex> NBA.Stats.TeamYearByYearStats.get(TeamID: 1610612744)
{:ok, %{"TeamYearByYearStats" => [%{...}, ...]}}

get!(params \\ [], opts \\ [])

(since 0.1.0)