NBA.Stats.WinProbabilityPBP (nba_api_ex v0.1.0)

Provides functions to interact with the NBA stats API for WinProbabilityPBP.

See get/2 for parameter and usage details.

Summary

Functions

get(params \\ [GameID: nil, RunType: "each second"], opts \\ [])

(since 0.1.0)

Fetches WinProbabilityPBP data.

Parameters

  • params: A keyword list of parameters to filter the data.

    • GameID: (Required) The game ID.

    • RunType: The run type.

  • opts: A keyword list of additional options for the request, such as headers or timeout settings.

Returns

  • {:ok, data}: On success, returns the data from the API.
  • {:error, reason}: On failure, returns an error tuple with the reason.

Example

iex> NBA.Stats.WinProbabilityPBP.get(GameID: "0022100001", RunType: "single")
{:ok, %{"WinProbabilityPBP" => [%{...}, ...]}}

get!(params \\ [], opts \\ [])

(since 0.1.0)