NBA.Stats.FranchiseHistory (nba_api_ex v0.1.0)
View SourceFetches franchise history data for every team.
Summary
Functions
Fetches franchise history data for a given season year.
Functions
Fetches franchise history data for a given season year.
Parameters
params: A keyword list of parameters to filter the data.LeagueID: The league ID.- Type(s):
String - Example:
LeagueID: "00" - Default:
"00"
- Type(s):
opts: A keyword list of additional options for the request, such as headers or timeout settings.- For a list of available options, see the Req documentation.
Returns
{:ok, data}: On success, returns the data from the API.{:error, reason}: On failure, returns an error tuple with the reason.
Example
iex> NBA.Stats.FranchiseHistory.get(LeagueID: "00")
{:ok, %{"franchisehistory" => [%{...}, ...]}}