NBA.Stats.GameRotation (nba_api_ex v0.1.0)
View SourceHandles requests to the NBA stats game rotation endpoint.
Summary
Functions
Fetches game rotation data for a specific game.
Functions
Fetches game rotation data for a specific game.
Parameters
params: A keyword list of parameters, including:opts: A keyword list of additional options for the request, such as headers or timeout settings.
Returns
{:ok, data}: On success, returns a map containing the game rotation data.{:error, reason}: On failure, returns an error tuple with the reason for failure.
Example
iex> NBA.Stats.GameRotation.get(GameID: "0022200001")
{:ok, %{status: 200, data: %{"GameRotation" => [...]}}}