NBA.Stats.ISTStandings (nba_api_ex v0.1.0)
View SourceFetches NBA Cup standings data.
Summary
Functions
Fetches NBA Cup standings data.
Functions
Fetches NBA Cup standings data.
Parameters
params: A keyword list of parameters, including:LeagueID: The league ID.- Type(s): Numeric
String. - Default:
"00"(NBA). - Example:
LeagueID: "10"(for WNBA). - Valueset:
"00"(NBA)"01"(ABA)"10"(WNBA)"20"(G-League)
- Type(s): Numeric
Season: (Required) The season for which to fetch standings.- Type(s): Numeric
String. - Default:
"2023-24"(current season). - Example:
Season: "2022-23"(for the previous season).
- Type(s): Numeric
Section: The type of season (default is "group").- Type(s):
String. - Default:
"group"(for group standings). - Example:
Section: "wildcard" - Valueset:
"group"(Group standings)"wildcard"(Wildcard standings)
- Type(s):
opts: A keyword list of additional options for the request, such as headers or timeout settings.- For a full list of options, see the Req documentation.
Returns
{:ok, data}: On success, returns a map containing the IST standings data.{:error, reason}: On failure, returns an error tuple with the reason for failure.
Example
iex> NBA.Stats.ISTStandings.get(Season: "2023-24")
{:ok, %{"leagueId" => "00", "seasonYear" => "2023-24", "teams" => [...]}}