NBA.Stats.LeagueStandingsV3 (nba_api_ex v0.1.0)
View SourceProvides functions to interact with the NBA stats API for league standings v3.
See get/2 for parameter and usage details.
Summary
Functions
Fetches league standings v3 data.
Functions
Fetches league standings v3 data.
Parameters
params: A keyword list of parameters to filter the data.SeasonYear: (Required) The season year.- Type(s):
String - Example:
SeasonYear: "2024-25" - Default:
nil - Pattern:
^\d{4}-\d{2}$
- Type(s):
LeagueID: The league ID (e.g., "00" for NBA).- Type(s):
String - Example:
LeagueID: "00" - Default:
"00" - Valueset:
"00"(NBA)"01"(ABA)"10"(WNBA)"20"(G League)
- Type(s):
SeasonType: The type of season.- Type(s):
String - Example:
SeasonType: "Regular Season" - Default:
"Regular Season" - Valueset:
"Regular Season""Pre Season"
- Type(s):
opts: A keyword list of additional options for the request, such as headers or timeout settings.- For a full list of options, see the Req documentation.
Returns
{:ok, data}: On success, returns the data from the API.{:error, reason}: On failure, returns an error tuple with the reason.
Example
iex> NBA.Stats.LeagueStandingsV3.get(LeagueID: "00", Season: "2024-25", SeasonType: "Regular Season")
{:ok, %{"LeagueStandingsV3" => [%{...}, ...]}}