NBA.Stats.PlayerGameLog (nba_api_ex v0.1.0)
View SourceProvides functions to interact with the NBA stats API for PlayerGameLog.
See get/2 for parameter and usage details.
Summary
Functions
Fetches PlayerGameLog data.
Parameters
params: A keyword list of parameters to filter the data.PlayerID: (Required) The player ID.Season: (Required) The season.- Type(s):
String - Example:
Season: "2024-25" - Default:
nil
- Type(s):
SeasonType: The type of season.- Type(s):
String - Example:
SeasonType: "Regular Season" - Default:
"Regular Season" - Valueset:
"Regular Season""Pre Season""Playoffs""All-Star""All Star"
- Type(s):
LeagueID: The league ID.- Type(s):
String - Example:
LeagueID: "00" - Default:
"00" - Valueset:
"00"(NBA)"01"(ABA)"10"(WNBA)"20"(G League)
- Type(s):
DateTo: The end date.- Type(s):
String - Example:
DateTo: "01/31/2025" - Default:
nil
- Type(s):
DateFrom: The start date.- Type(s):
String - Example:
DateFrom: "01/01/2025" - Default:
nil
- Type(s):
opts: A keyword list of additional options for the request, such as headers or timeout settings.- For a full list of options, see the Req documentation.
Returns
{:ok, data}: On success, returns the data from the API.{:error, reason}: On failure, returns an error tuple with the reason.
Example
iex> NBA.Stats.PlayerGameLog.get(PlayerID: 201939, Season: "2024-25")
{:ok, %{"PlayerGameLog" => [%{...}, ...]}}