NBA.Stats.PlayerNextNGames (nba_api_ex v0.1.0)
View SourceProvides functions to interact with the NBA stats API for PlayerNextNGames.
See get/2 for parameter and usage details.
Summary
Functions
Fetches PlayerNextNGames data.
Parameters
params: A keyword list of parameters to filter the data.PlayerID: (Required) The player ID.Season: (Required) The season.- Type(s):
String - Example:
Season: "2024-25" - Default:
nil - Pattern:
^(\d{4}-\d{2})|(ALL)$
- Type(s):
NumberOfGames: The number of upcoming games to return.- Type(s):
Integer - Example:
NumberOfGames: 5 - Default:
nil
- Type(s):
SeasonType: The season type.- Type(s):
String - Example:
SeasonType: "Regular Season" - Default:
nil - Valueset:
"Regular Season""Pre Season""Playoffs""All-Star""All Star"
- Type(s):
LeagueID: The league ID.- Type(s):
String - Example:
LeagueID: "00" - Default:
"00" - Pattern:
^\d{2}$
- Type(s):
opts: A keyword list of additional options for the request, such as headers or timeout settings.- For a full list of options, see the Req documentation.
Returns
{:ok, data}: On success, returns the data from the API.{:error, reason}: On failure, returns an error tuple with the reason.
Example
iex> NBA.Stats.PlayerNextNGames.get(PlayerID: 201939, NumberOfGames: 5, Season: "2024-25", SeasonType: "Regular Season")
{:ok, %{"PlayerNextNGames" => [%{...}, ...]}}