NBA.Stats.PlayoffPicture (nba_api_ex v0.1.0)
View SourceProvides functions to interact with the NBA stats API for PlayoffPicture.
See get/2 for parameter and usage details.
Summary
Functions
Fetches PlayoffPicture data.
Functions
Fetches PlayoffPicture data.
Parameters
params: A keyword list of parameters to filter the data.opts: A keyword list of additional options for the request, such as headers or timeout settings.- For a full list of options, see the Req documentation.
Returns
{:ok, data}: On success, returns the data from the API.{:error, reason}: On failure, returns an error tuple with the reason.
Example
iex> NBA.Stats.PlayoffPicture.get(LeagueID: "00", SeasonID: "22022")
{:ok, %{"PlayoffPicture" => [%{...}, ...]}}