NBA.Stats.TeamGameLog (nba_api_ex v0.1.0)
View SourceProvides functions to interact with the NBA stats API for TeamGameLog.
See get/2 for parameter and usage details.
Summary
Functions
Fetches TeamGameLog data.
Parameters
params: A keyword list of parameters to filter the data.Season: (Required) The season.- Type(s):
String - Default:
nil
- Type(s):
TeamID: (Required) The team ID.- Type(s):
Integer - Default:
nil
- Type(s):
SeasonType: The season type.- Type(s):
String - Default:
"Regular Season" - Valueset:
"Regular Season""Pre Season""Playoffs""All-Star""All Star""Preseason"
- Type(s):
LeagueID: The league ID.- Type(s):
String - Default:
"00"
- Type(s):
DateTo: The end date (MM/DD/YYYY).- Type(s):
String - Default:
nil
- Type(s):
DateFrom: The start date (MM/DD/YYYY).- Type(s):
String - Default:
nil
- Type(s):
opts: A keyword list of additional options for the request, such as headers or timeout settings.- For a full list of options, see the Req documentation.
Returns
{:ok, data}: On success, returns the data from the API.{:error, reason}: On failure, returns an error tuple with the reason.
Example
iex> NBA.Stats.TeamGameLog.get(Season: "2024-25", TeamID: 1610612744)
{:ok, %{"TeamGameLog" => [%{...}, ...]}}