NBA.Stats.TeamGameStreakFinder (nba_api_ex v0.1.0)
View SourceProvides functions to interact with the NBA stats API for TeamGameStreakFinder.
Summary
Functions
Fetches TeamGameStreakFinder data.
Functions
Fetches TeamGameStreakFinder data.
Parameters
params: A keyword list of parameters to filter the data.Note: This endpoint also supports a wide range of advanced stat filters in the form of
LtX,GtX, andEqX(e.g.,LtPTS,GtAST,EqREB), whereXis a stat name. These acceptIntegerorFloatvalues and default tonil.ActiveStreaksOnly: Only include active streaks.- Type(s):
String - Default:
nil - Valueset:
"Y""N"
- Type(s):
ActiveTeamsOnly: Only include active teams.- Type(s):
String - Default:
nil - Valueset:
"Y""N"
- Type(s):
Conference: Conference filter.- Type(s):
String - Default:
nil - Valueset:
"East""West"
- Type(s):
DateFrom: Start date filter (MM/DD/YYYY).- Type(s):
String - Default:
nil
- Type(s):
DateTo: End date filter (MM/DD/YYYY).- Type(s):
String - Default:
nil
- Type(s):
Division: Division filter.- Type(s):
String - Default:
nil - Valueset:
"Atlantic""Central""Northwest""Pacific""Southeast""Southwest""East""West"
- Type(s):
GameID: NBA game ID.- Type(s):
String - Default:
nil
- Type(s):
LeagueID: The league ID.- Type(s):
String - Default:
"00"
- Type(s):
Location: Game location.- Type(s):
String - Default:
nil - Valueset:
"Home""Road"
- Type(s):
LStreak: Losing streak count.- Type(s):
Integer - Default:
nil
- Type(s):
MinGames: Minimum number of games played.- Type(s):
Integer - Default:
nil
- Type(s):
Outcome: Game outcome.- Type(s):
String - Default:
nil - Valueset:
"W""L"
- Type(s):
PORound: Playoff round.- Type(s):
Integer - Default:
nil
- Type(s):
Season: The NBA season.- Type(s):
String - Default:
nil
- Type(s):
SeasonSegment: The season segment.- Type(s):
String - Default:
nil - Valueset:
"Post All-Star""Pre All-Star"
- Type(s):
SeasonType: The season type.- Type(s):
String - Default:
"Regular Season" - Valueset:
"Regular Season""Pre Season""Playoffs""All Star"
- Type(s):
TeamID: The team ID.- Type(s):
Integer - Default:
nil
- Type(s):
VsConference: Opponent conference.- Type(s):
String - Default:
nil - Valueset:
"East""West"
- Type(s):
VsDivision: Opponent division.- Type(s):
String - Default:
nil - Valueset:
"Atlantic""Central""Northwest""Pacific""Southeast""Southwest""East""West"
- Type(s):
VsTeamID: Opponent team ID.- Type(s):
Integer - Default:
nil
- Type(s):
WStreak: Winning streak count.- Type(s):
Integer - Default:
nil
- Type(s):
opts: A keyword list of additional options for the request, such as headers or timeout settings.- For a full list of options, see the Req documentation.
Returns
{:ok, data}: On success, returns the data from the API.{:error, reason}: On failure, returns an error tuple with the reason.
Example
iex> NBA.Stats.TeamGameStreakFinder.get(TeamID: 1610612744, Season: "2024-25")
{:ok, %{"TeamGameStreakFinder" => [%{...}, ...]}}