NBA.Stats.VideoStatus (nba_api_ex v0.1.0)
View SourceProvides functions to interact with the NBA stats API for VideoStatus.
See get/2 for parameter and usage details.
Summary
Functions
Fetches VideoStatus data.
Functions
Fetches VideoStatus data.
Parameters
params: A keyword list of parameters to filter the data.opts: A keyword list of additional options for the request, such as headers or timeout settings.- For a full list of options, see the Req documentation.
Returns
{:ok, data}: On success, returns the data from the API.{:error, reason}: On failure, returns an error tuple with the reason.
Example
iex> NBA.Stats.VideoStatus.get(GameDate: "2025-06-06", LeagueID: "00")
{:ok, %{"VideoStatus" => [%{...}, ...]}}